@@ -4,6 +4,9 @@ from typing import Callable
 # Django
 from django.http import HttpRequest, HttpResponse
 
+# Local
+from .constants import TURBO_STREAM_MIME_TYPE
+
 
 class TurboStreamMiddleware:
     """Adds bool attribute 'accept_turbo_stream' to request if the Turbo Stream accept header is present."""
@@ -12,7 +15,7 @@ class TurboStreamMiddleware:
         self.get_response = get_response
 
     def __call__(self, request: HttpRequest) -> HttpResponse:
-        request.accept_turbo_stream = "text/html; turbo-stream" in request.headers.get(
+        request.accept_turbo_stream = TURBO_STREAM_MIME_TYPE in request.headers.get(
             "Accept", ""
         )
         return self.get_response(request)
